@@ -1,4 +1,4 @@
-/* organise.c (acdc) - copyright Mike Arnautov 1990-2023.
+/* organise.c (acdc) - copyright Mike Arnautov 1990-2022.
  * Licensed under GPL, version 3 or later (see the supplied LICENCE file).
  *
  *                           
@@ -72,7 +72,7 @@
  */
  
 #include <stdio.h>
-/* #include <ctype.h> */
+// #include <ctype.h>
 #include <string.h>
 #include <stdarg.h>
 
@@ -186,7 +186,7 @@ void mandate (char *item, int type, ...)
       ap = addsymb (AUTOSYMBOL, item, type, type_counts[type]++);
       if (type == OBJ || type == WORD)
       {
-        if (!(np = fndsymb(VOCAB, item))) /* Might be declared as NOISE! */
+        if (!(np = fndsymb(VOCAB, item))) // Might be declared as NOISE!
            np = storword (item, type, next_vocaddr);
 /* The ++ in the following line is an error, effectively wasting a refno.
  * However, fixing it would break upward compatibility of saved games!
@@ -286,10 +286,8 @@ void organise(void)
    fprintf (code_file, "#include \"adv3.h\"\n");
 
    next_addr = 0;
-/*
-//   if (debug)     // Declarations over - if source output
-//      debug = 2;  // is required, turn it on!
-*/
+//   if (debug)     /* Declarations over - if source output */
+//      debug = 2;  /* is required, turn it on! */
 
    if (*title)
       strcpy (dbname, title);
@@ -835,7 +833,7 @@ void organise(void)
    fprintf (defs_file, "#define CENTRE_START 0%o\n", CENTRE_START);
    if (style > 10)
      fprintf (defs_file, "#define VHOLDER      0%o\n", VHOLDER);
-     fprintf (defs_file, "#define UTF8         %d\n",  utf8);
+     fprintf (defs_file, "#define UTF8         %d\n",  1);
    stage = 1;        /* Restore stage value */
    return;
 }
